summaryrefslogtreecommitdiff
path: root/Debian/Debhelper/Buildsystem
diff options
context:
space:
mode:
authorJoey Hess <joey@gnu.kitenet.net>2009-04-20 15:50:11 -0400
committerJoey Hess <joey@gnu.kitenet.net>2009-04-20 15:50:11 -0400
commita843fb46e30ab4795a032a0a48e35a30b5c7299d (patch)
tree66a015f051ad5b83bcd3eba9566d872134af7108 /Debian/Debhelper/Buildsystem
parent0f0e1958b7a71c6323703bbe6415f2f333555f88 (diff)
rename autotools to autoconf
It seems bette to use the more specific name in case we later want a separate module for automake.
Diffstat (limited to 'Debian/Debhelper/Buildsystem')
-rw-r--r--Debian/Debhelper/Buildsystem/autoconf.pm (renamed from Debian/Debhelper/Buildsystem/autotools.pm)10
1 files changed, 5 insertions, 5 deletions
diff --git a/Debian/Debhelper/Buildsystem/autotools.pm b/Debian/Debhelper/Buildsystem/autoconf.pm
index 3bbd2740..fcdc2567 100644
--- a/Debian/Debhelper/Buildsystem/autotools.pm
+++ b/Debian/Debhelper/Buildsystem/autoconf.pm
@@ -1,10 +1,10 @@
# A buildsystem plugin for handling autotools based projects
#
# Copyright: © 2008 Joey Hess
# © 2008-2009 Modestas Vainius
# License: GPL-2+
-package Debian::Debhelper::Buildsystem::autotools;
+package Debian::Debhelper::Buildsystem::autoconf;
use strict;
use File::Spec;
@@ -12,7 +12,7 @@ use Debian::Debhelper::Dh_Lib;
use base 'Debian::Debhelper::Buildsystem::makefile';
sub DESCRIPTION {
- "GNU Autotools (configure)"
+ "GNU Autoconf (configure)"
}
sub check_auto_buildable {
@@ -42,8 +42,8 @@ sub configure {
push @opts, "--disable-maintainer-mode";
push @opts, "--disable-dependency-tracking";
# Provide --host only if different from --build, as recommended in
# autotools-dev README.Debian: When provided (even if equal) autotools
# 2.52+ switches to cross-compiling mode.
if (dpkg_architecture_value("DEB_BUILD_GNU_TYPE")
ne dpkg_architecture_value("DEB_HOST_GNU_TYPE")) {
push @opts, "--host=" . dpkg_architecture_value("DEB_HOST_GNU_TYPE");
@@ -1,10 +1,10 @@
-# A buildsystem plugin for handling autotools based projects
+# A buildsystem plugin for handling autoconf based projects
#
# Copyright: © 2008 Joey Hess
@@ -42,8 +42,8 @@ sub configure {
push @opts, "--disable-dependency-tracking";
# Provide --host only if different from --build, as recommended in
- # autotools-dev README.Debian: When provided (even if equal) autotools
- # 2.52+ switches to cross-compiling mode.
+ # autotools-dev README.Debian: When provided (even if equal)
+ # autoconf 2.52+ switches to cross-compiling mode.
if (dpkg_architecture_value("DEB_BUILD_GNU_TYPE")
ne dpkg_architecture_value("DEB_HOST_GNU_TYPE")) {